These aliases follow common R naming style while preserving the original
uppercase function names used in earlier versions of the package.
Usage
ash(...)
lbfp(...)
glbfp(...)
ash_estimate(...)
lbfp_estimate(...)
glbfp_estimate(...)
compute_di(...)
Arguments
- ...
Arguments passed to the corresponding uppercase function.
Value
The same object returned by the corresponding uppercase function.